class Mode:
    boards = "boards"
    users = "users"
    pics = "pics"
    clips = "videos"
    gifs = "gifs"


class Relevance:
    popular = "&sort=popular-all"
    latest = "&sort=latest"
    relevance = ""
